/*************************************************************
 * Author:    wangjiangyuan (wangjiangyuan@agora.io)
 * Date  :    Oct 21th, 2020
 * Module:    Agora SD-RTN SDK RTC C API demo application.
 *
 *
 * This is a part of the Agora RTC Service SDK.
 * Copyright (C) 2020 Agora IO
 * All rights reserved.
 *
 *************************************************************/

#ifndef __FILE_PARSER_PRIV_H__
#define __FILE_PARSER_PRIV_H__

#include <stdio.h>
#include <stdint.h>
#include "file_parser.h"

#define LOGS(fmt, ...) fprintf(stdout, "" fmt "\n", ##__VA_ARGS__)
#define LOGD(fmt, ...) fprintf(stdout, "[DBG] " fmt "\n", ##__VA_ARGS__)
#define LOGI(fmt, ...) fprintf(stdout, "[INF] " fmt "\n", ##__VA_ARGS__)
#define LOGW(fmt, ...) fprintf(stdout, "[WRN] " fmt "\n", ##__VA_ARGS__)
#define LOGE(fmt, ...) fprintf(stdout, "[ERR] " fmt "\n", ##__VA_ARGS__)

typedef struct media_parser_s media_parser_t;
struct media_parser_s {
	int type;
	int codec;
	void *p_ctx;
	parser_cfg_t parser_cfg;

	int (*open)(media_parser_t *h, const char *path);
	int (*obtain_frame)(media_parser_t *h, frame_t *p_frame);
	int (*release_frame)(media_parser_t *h, frame_t *p_frame);
	int (*reset)(media_parser_t *h);
	int (*close)(media_parser_t *h);
};

/**
 * The definition of the video_data_type_e enum.
 */
typedef enum {
	/**
     * 2: H264
     */
	VIDEO_DATA_TYPE_H264 = 2,
	/**
     * 6: generic
     */
	VIDEO_DATA_TYPE_GENERIC = 6,
	/**
     * 20: generic JPEG
     */
	VIDEO_DATA_TYPE_GENERIC_JPEG = 20,
} video_data_type_e;

/**
 * Audio codec type list.
 */
typedef enum {
	/**
     * 1: OPUS
     */
	AUDIO_DATA_TYPE_OPUS = 1,
	/**
     * 5: G722
     */
	AUDIO_DATA_TYPE_G722 = 5,
	/**
     * 8: AACLC
     */
	AUDIO_DATA_TYPE_AACLC = 8,
	/**
     * 9: HEAAC
     */
	AUDIO_DATA_TYPE_HEAAC = 9,
	/**
     * 100: RAW PCM (only supported by RTSA_Lite with audio codec)
     */
	AUDIO_DATA_TYPE_PCM = 100,
	/**
     * 253: GENERIC
     */
	AUDIO_DATA_TYPE_GENERIC = 253,
} audio_data_type_e;

#endif /* __FILE_PARSER_PRIV_H__ */